% Auto-generated chapter 42 for nasai
% Hadiths in this chapter: 98

\hadithdefcmd{nasai}{4263}{أَخْبَرَنَا الإِمَامُ أَبُو عَبْدِ الرَّحْمَنِ النَّسَائِيُّ، بِمِصْرَ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنْ سُوَيْدِ بْنِ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّيْدِ فَقَالَ ‏ "‏ إِذَا أَرْسَلْتَ كَلْبَكَ فَاذْكُرِ اسْمَ اللَّهِ عَلَيْهِ فَإِنْ أَدْرَكْتَهُ لَمْ يَقْتُلْ فَاذْبَحْ وَاذْكُرِ اسْمَ اللَّهِ عَلَيْهِ وَإِنْ أَدْرَكْتَهُ قَدْ قَتَلَ وَلَمْ يَأْكُلْ فَكُلْ فَقَدْ أَمْسَكَهُ عَلَيْكَ فَإِنْ وَجَدْتَهُ قَدْ أَكَلَ مِنْهُ فَلاَ تَطْعَمْ مِنْهُ شَيْئًا فَإِنَّمَا أَمْسَكَ عَلَى نَفْسِهِ وَإِنْ خَالَطَ كَلْبُكَ كِلاَبًا فَقَتَلْنَ فَلَمْ يَأْكُلْنَ فَلاَ تَأْكُلْ مِنْهُ شَيْئًا فَإِنَّكَ لاَ تَدْرِي أَيُّهَا قَتَلَ ‏"‏ ‏.‏\hadithno{4263}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Adiyy bin Hatim that:he asked the Messenger of Allah about hunting. He said: "When you release your dog, mention the name of Allah over him, and if you catch up with him and he has not killed (the game), then slaughter it and mention the name of Allah over it. If you catch up with him and he has killed (the game) but has not eaten any of it, then eat, for he caught it for you. If you find that the has eaten some of it, then do not eat any of it for he caught it for himself. If there are other dogs with your dog and they have killed (the game) but have not eaten any of it, then do not eat any of it, because you do not know which of them killed it}}
\hadithdefcmd{nasai}{4264}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ زَكَرِيَّا، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَيْدِ الْمِعْرَاضِ فَقَالَ ‏"‏ مَا أَصَبْتَ بِحَدِّهِ فَكُلْ وَمَا أَصَبْتَ بِعَرْضِهِ فَهُوَ وَقِيذٌ ‏"‏ ‏.‏ وَسَأَلْتُهُ عَنِ الْكَلْبِ فَقَالَ ‏"‏ إِذَا أَرْسَلْتَ كَلْبَكَ فَأَخَذَ وَلَمْ يَأْكُلْ فَكُلْ فَإِنَّ أَخْذَهُ ذَكَاتُهُ وَإِنْ كَانَ مَعَ كَلْبِكَ كَلْبٌ آخَرُ فَخَشِيتَ أَنْ يَكُونَ أَخَذَ مَعَهُ فَقَتَلَ فَلاَ تَأْكُلْ فَإِنَّكَ إِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ وَلَمْ تُسَمِّ عَلَى غَيْرِهِ ‏"‏ ‏.‏\hadithno{4264}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that `Adiyy bin Abi Hatim said:"I asked the Messenger of Allah about hunting with a Mi`rad. He said: 'If you strike (the game) with its sharp point, then eat, but if you strike it with its broad side, then the animal has been killed with a blow.' I asked him about dogs and he said: 'If you release your dog and he catches (the game) but does not eat it, then eat, because his catching it is its slaughter. If you find another dog with your dog and you fear that it caught (the game) with him and killed it, then do not eat, for you said the name of Allah over your dog, but you did not say His name over the other one}}
\hadithdefcmd{nasai}{4265}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا أَبُو عَبْدِ الصَّمَدِ عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، قَالَ حَدَّثَنَا مَنْصُورٌ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ أُرْسِلُ الْكَلْبَ الْمُعَلَّمَ فَيَأْخُذُ ‏.‏ فَقَالَ ‏"‏ إِذَا أَرْسَلْتَ الْكَلْبَ الْمُعَلَّمَ وَذَكَرْتَ اسْمَ اللَّهِ عَلَيْهِ فَأَخَذَ فَكُلْ ‏"‏ ‏.‏ قُلْتُ وَإِنْ قَتَلَ قَالَ ‏"‏ وَإِنْ قَتَلَ ‏"‏ ‏.‏ قُلْتُ أَرْمِي بِالْمِعْرَاضِ ‏.‏ قَالَ ‏"‏ إِذَا أَصَابَ بِحَدِّهِ فَكُلْ وَإِذَا أَصَابَ بِعَرْضِهِ فَلاَ تَأْكُلْ ‏"‏ ‏.‏\hadithno{4265}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was Narrated from 'Adiyy bin Hatim the he asked the Messenger of Allah :"I release my trained dog and he catches (game)." He said: "If you release the trained dog and you say the name of Allah over him, and he catches (something), then eat." I said: "Even if he kills it?" He said: shoot with the Mirad." He said: "If it hits (the game) with its sharp point, then eat, but if it hits it with its broad side, then do not eat}}
\hadithdefcmd{nasai}{4266}{أَخْبَرَنِي مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مُحَمَّدٍ الْكُوفِيُّ الْمُحَارِبِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، قَالَ سَمِعْتُ رَبِيعَةَ بْنَ يَزِيدَ، يَقُولُ أَنْبَأَنَا أَبُو إِدْرِيسَ، عَائِذُ اللَّهِ قَالَ سَمِعْتُ أَبَا ثَعْلَبَةَ الْخُشَنِيَّ، يَقُولُ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا بِأَرْضِ صَيْدٍ أَصِيدُ بِقَوْسِي وَأَصِيدُ بِكَلْبِي الْمُعَلَّمِ وَبِكَلْبِي الَّذِي لَيْسَ بِمُعَلَّمٍ ‏.‏ فَقَالَ ‏ "‏ مَا أَصَبْتَ بِقَوْسِكَ فَاذْكُرِ اسْمَ اللَّهِ عَلَيْهِ وَكُلْ وَمَا أَصَبْتَ بِكَلْبِكَ الْمُعَلَّمِ فَاذْكُرِ اسْمَ اللَّهِ وَكُلْ وَمَا أَصَبْتَ بِكَلْبِكَ الَّذِي لَيْسَ بِمُعَلَّمٍ فَأَدْرَكْتَ ذَكَاتَهُ فَكُلْ ‏"‏ ‏.‏\hadithno{4266}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Tha'labah Al-Khushani said:"I said: 'O Messenger of Allah, we live in a land where people hunt, and I hunt with my bow and with my trained dog, and with trained dog, and with my dog which ins not trained.' He said: 'whatever you catch with your bow, mention the name of Allah over it and eat. Whatever you catch with the trained dog, mention the name of Allah over it and eat. Whatever you catch with your untrained dog and you reach it while it is still alive, then slaughter it, and eat.""( Sahih)}}
\hadithdefcmd{nasai}{4267}{أَخْبَرَنَا مُحَمَّدُ بْنُ زُنْبُورٍ أَبُو صَالِحٍ الْمَكِّيُّ، قَالَ حَدَّثَنَا فُضَيْلُ بْنُ عِيَاضٍ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أُرْسِلُ كِلاَبِي الْمُعَلَّمَةَ فَيُمْسِكْنَ عَلَىَّ فَآكُلُ قَالَ ‏"‏ إِذَا أَرْسَلْتَ كِلاَبَكَ الْمُعَلَّمَةَ فَأَمْسَكْنَ عَلَيْكَ فَكُلْ ‏"‏ ‏.‏ قُلْتُ وَإِنْ قَتَلْنَ قَالَ ‏"‏ وَإِنْ قَتَلْنَ ‏"‏ ‏.‏ قَالَ ‏"‏ مَا لَمْ يَشْرَكْهُنَّ كَلْبٌ مِنْ سِوَاهُنَّ ‏"‏ ‏.‏ قُلْتُ أَرْمِي بِالْمِعْرَاضِ فَيَخْزِقُ ‏.‏ قَالَ ‏"‏ إِنْ خَزَقَ فَكُلْ وَإِنْ أَصَابَ بِعَرْضِهِ فَلاَ تَأْكُلْ ‏"‏ ‏.‏\hadithno{4267}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"I said: 'O Messenger of Allah, I release my trained dogs and they catch (game) for me; can I eat It? He said: 'When you release your trained dogs and they catch (game) for you, then eat.' I said: 'Even if they kill it.' He said: 'So long as no other dogs have joined them." I said: 'I shoot with the Mirad. And they penetrate (the game).' He said 'If they penetrate it, then eat, but if the broad said strikes it, then do not eat}}
\hadithdefcmd{nasai}{4268}{أَخْبَرَنِي عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ، قَالَ حَدَّثَنَا مُوسَى بْنُ أَعْيَنَ، عَنْ مَعْمَرٍ، عَنْ عَاصِمِ بْنِ سُلَيْمَانَ، عَنْ عَامِرٍ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّيْدِ فَقَالَ ‏ "‏ إِذَا أَرْسَلْتَ كَلْبَكَ فَخَالَطَتْهُ أَكْلُبٌ لَمْ تُسَمِّ عَلَيْهَا فَلاَ تَأْكُلْ فَإِنَّكَ لاَ تَدْرِي أَيَّهَا قَتَلَهُ ‏"‏ ‏.‏\hadithno{4268}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Adiyy bin Hatim that he asked the Messenger of Allah about hunting and he said:"If you release your dog and other dogs over with you have not mentioned the name of Allah join him, then do not eat (what they catch), because you do not know which of them killed it (the game)}}
\hadithdefcmd{nasai}{4269}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا زَكَرِيَّا، - وَهُوَ ابْنُ أَبِي زَائِدَةَ - قَالَ حَدَّثَنَا عَامِرٌ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْكَلْبِ فَقَالَ ‏ "‏ إِذَا أَرْسَلْتَ كَلْبَكَ فَسَمَّيْتَ فَكُلْ وَإِنْ وَجَدْتَ كَلْبًا آخَرَ مَعَ كَلْبِكَ فَلاَ تَأْكُلْ فَإِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ وَلَمْ تُسَمِّ عَلَى غَيْرِهِ ‏"‏ ‏.‏\hadithno{4269}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"I asked the Messenger of Allah about dogs and he said: 'If you release your dog and say the name of Allah, then eat, but if you find another dog with your dog then do not eat, for you only said the name of Allah over your dog, not any other}}
\hadithdefcmd{nasai}{4270}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ جَعْفَرٍ - قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، قَالَ حَدَّثَنَا الشَّعْبِيُّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، - وَكَانَ لَنَا جَارًا وَدَخِيلاً وَرَبِيطًا بِالنَّهْرَيْنِ - أَنَّهُ سَأَلَ النَّبِيَّ صلى الله عليه وسلم قَالَ أُرْسِلُ كَلْبِي فَأَجِدُ مَعَ كَلْبِي كَلْبًا قَدْ أَخَذَ لاَ أَدْرِي أَيَّهُمَا أَخَذَ قَالَ ‏ "‏ لاَ تَأْكُلْ فَإِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ وَلَمْ تُسَمِّ عَلَى غَيْرِهِ ‏"‏ ‏.‏\hadithno{4270}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ash-Sha bi that; "Adiyy bin Hatim who was neighbor, Dakhilan and Rabitan at An-Nahrain narrated that he asked the Prophet Saying:'I releaser my dog and I find another dog with my dog, and I do not know which of them caught (the game).' He said: 'Do not eat, for your only said the name of Allah over your dog, and not over any other dog}}
\hadithdefcmd{nasai}{4271}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ حَدَّثَنَا عَنِ الشَّعْبِيِّ، عَنْ عَدِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ ذَلِكَ ‏.‏\hadithno{4271}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Adiyy bin Hatim:A similar report was narrated from 'Adiyy bin Hatim}}
\hadithdefcmd{nasai}{4272}{أَخْبَرَنَا سُلَيْمَانُ بْنُ عُبَيْدِ اللَّهِ بْنِ عَمْرٍو الْغَيْلاَنِيُّ الْبَصْرِيُّ، قَالَ حَدَّثَنَا بَهْزٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي السَّفَرِ، عَنْ عَامِرٍ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قُلْتُ أُرْسِلُ كَلْبِي ‏.‏ قَالَ ‏ "‏ إِذَا أَرْسَلْتَ كَلْبَكَ فَسَمَّيْتَ فَكُلْ وَإِنْ أَكَلَ مِنْهُ فَلاَ تَأْكُلْ فَإِنَّمَا أَمْسَكَ عَلَى نَفْسِهِ وَإِذَا أَرْسَلْتَ كَلْبَكَ فَوَجَدْتَ مَعَهُ غَيْرَهُ فَلاَ تَأْكُلْ فَإِنَّكَ إِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ وَلَمْ تُسَمِّ عَلَى غَيْرِهِ ‏"‏ ‏.‏\hadithno{4272}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"I asked the Messenger of Allah: 'I release my dog. He said: 'If you release your dog and mention the name of Allah, then eat. But it he has eaten some of it, the do not eats, for the caught it for himself. If you release your dog then you find another dog with it, then do not eat, for you said the name of Allah over your dog, and not over any other}}
\hadithdefcmd{nasai}{4273}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنِ ابْنِ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، وَعَنِ الْحَكَمِ، عَنِ الشَّعْبِيِّ، وَعَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قُلْتُ أُرْسِلُ كَلْبِي فَأَجِدُ مَعَ كَلْبِي كَلْبًا آخَرَ لاَ أَدْرِي أَيَّهُمَا أَخَذَ قَالَ ‏ "‏ لاَ تَأْكُلْ فَإِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ وَلَمْ تُسَمِّ عَلَى غَيْرِهِ ‏"‏ ‏.‏\hadithno{4273}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"I asked the Messenger of Allah: 'I release my dog, and I find another dog with mine, and I do not know which mine, and I do not know which of them caught (the game).' He said: 'do not eat it, for you said the name of Allah over your dog, but not over any other}}
\hadithdefcmd{nasai}{4274}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ هَارُونَ - أَنْبَأَنَا زَكَرِيَّا، وَعَاصِمٌ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَيْدِ الْمِعْرَاضِ فَقَالَ ‏"‏ مَا أَصَابَ بِحَدِّهِ فَكُلْ وَمَا أَصَابَ بِعَرْضِهِ فَهُوَ وَقِيذٌ ‏"‏ ‏.‏ قَالَ وَسَأَلْتُهُ عَنْ كَلْبِ الصَّيْدِ فَقَالَ ‏"‏ إِذَا أَرْسَلْتَ كَلْبَكَ وَذَكَرْتَ اسْمَ اللَّهِ عَلَيْهِ فَكُلْ ‏"‏ ‏.‏ قُلْتُ وَإِنْ قَتَلَ قَالَ ‏"‏ وَإِنْ قَتَلَ فَإِنْ أَكَلَ مِنْهُ فَلاَ تَأْكُلْ وَإِنْ وَجَدْتَ مَعَهُ كَلْبًا غَيْرَ كَلْبِكَ وَقَدْ قَتَلَهُ فَلاَ تَأْكُلْ فَإِنَّكَ إِنَّمَا ذَكَرْتَ اسْمَ اللَّهِ عَزَّ وَجَلَّ عَلَى كَلْبِكَ وَلَمْ تَذْكُرْ عَلَى غَيْرِهِ ‏"‏ ‏.‏\hadithno{4274}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"I asked the Messenger of Allah about hunting with the Mirad. He said: 'whatever is struck with the sharp edge, eat, and whatever is hit with its broad side, it is an animal killed by a blow. "" He said: "And I asked him about hunting dogs. He said: 'If you release your dog and mention the name of Allah over it, then eat.,' I said: 'Even it he kills it?' He said: 'Even if he kills it?" He said: 'Even if he kills it. But if he has eaten some of it, then do not eat. And if you find another dog with your dog and he has killed (the game), then do not eat, for you only said the name of Allah over your dog, not over your dog, not over any other}}
\hadithdefcmd{nasai}{4275}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ، قَالَ حَدَّثَنَا مُوسَى بْنُ أَعْيَنَ، عَنْ مَعْمَرٍ، عَنْ عَاصِمِ بْنِ سُلَيْمَانَ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ الطَّائِيِّ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّيْدِ قَالَ ‏ "‏ إِذَا أَرْسَلْتَ كَلْبَكَ فَذَكَرْتَ اسْمَ اللَّهِ عَلَيْهِ فَقَتَلَ وَلَمْ يَأْكُلْ فَكُلْ وَإِنْ أَكَلَ مِنْهُ فَلاَ تَأْكُلْ فَإِنَّمَا أَمْسَكَهُ عَلَيْهِ وَلَمْ يُمْسِكْ عَلَيْكَ ‏"‏ ‏.‏\hadithno{4275}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Adiyy bin Hatim At-Tai that he asked the Messenger of Allah about hunting. He said:"If you release your dog and mention the name of Allah over him, and he kills (the game), but does not eat any of it, then eat. But if he has eaten from it, then do not eat, for he caught it for himself, and not for you}}
\hadithdefcmd{nasai}{4276}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي ابْنُ السَّبَّاقِ، قَالَ أَخْبَرَتْنِي مَيْمُونَةُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ جِبْرِيلُ عَلَيْهِ السَّلاَمُ لَكِنَّا لاَ نَدْخُلُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ ‏.‏ فَأَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ فَأَمَرَ بِقَتْلِ الْكِلاَبِ حَتَّى إِنَّهُ لَيَأْمُرُ بِقَتْلِ الْكَلْبِ الصَّغِيرِ ‏.‏\hadithno{4276}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Az-Zuhri said:"Ibn As-Sabbaq said: "Maimunah told me that Jibril, peace be upon him, said to the Messenger of Allah 'We (Angles) do not enter a house in which there is a dog or a picture, The next day the Messenger of Allah commanded that all dogs be killed, even small dogs}}
\hadithdefcmd{nasai}{4277}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْكِلاَبِ غَيْرَ مَا اسْتَثْنَى مِنْهَا ‏.‏\hadithno{4277}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah commanded that dogs be killed, except those which were exempted}}
\hadithdefcmd{nasai}{4278}{أَخْبَرَنَا وَهْبُ بْنُ بَيَانٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، قَالَ قَالَ ابْنُ شِهَابٍ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم رَافِعًا صَوْتَهُ يَأْمُرُ بِقَتْلِ الْكِلاَبِ فَكَانَتِ الْكِلاَبُ تُقْتَلُ إِلاَّ كَلْبَ صَيْدٍ أَوْ مَاشِيَةٍ ‏.‏\hadithno{4278}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Salim bin 'Abdullah narrated that his father said:"I heard the Messenger of Allah raise his voice with the command to kill dogs. All dogs were to be killed except dogs used for hunting or herding livestock}}
\hadithdefcmd{nasai}{4279}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْكِلاَبِ إِلاَّ كَلْبَ صَيْدٍ أَوْ كَلْبَ مَاشِيَةٍ ‏.‏\hadithno{4279}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah commanded that all dogs be killed except dogs used for hunting or herding livestock}}
\hadithdefcmd{nasai}{4280}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا يُونُسُ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْلاَ أَنَّ الْكِلاَبَ أُمَّةٌ مِنَ الأُمَمِ لأَمَرْتُ بِقَتْلِهَا فَاقْتُلُوا مِنْهَا الأَسْوَدَ الْبَهِيمَ وَأَيُّمَا قَوْمٍ اتَّخَذُوا كَلْبًا لَيْسَ بِكَلْبِ حَرْثٍ أَوْ صَيْدٍ أَوْ مَاشِيَةٍ فَإِنَّهُ يَنْقُصُ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏\hadithno{4280}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin Mughaffal that the Messenger of Allah said:"Were it not that dogs form one of the communities (or nations - of creatures), I would have commanded that they be killed. But kill those that are all black. Any people who keep a dog, except for dogs used for farming, hunting or herding livestock, one Qirat will be deducted from their reward each day}}
\hadithdefcmd{nasai}{4281}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، وَيَحْيَى بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، عَنْ أَبِي زُرْعَةَ، عَنْ عَبْدِ اللَّهِ بْنِ نُجَىٍّ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَلاَئِكَةُ لاَ تَدْخُلُ بَيْتًا فِيهِ صُورَةٌ وَلاَ كَلْبٌ وَلاَ جُنُبٌ ‏"‏ ‏.‏\hadithno{4281}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ali bin Abi Talib that the Prophet said:"The angels do not enter a house in which there is a picture, a dog or a person who is Junub}}
\hadithdefcmd{nasai}{4282}{أَخْبَرَنَا قُتَيْبَةُ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أَبِي طَلْحَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ ‏"‏ ‏.‏\hadithno{4282}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Talhah said:"The Messenger of Allah said: '; The angels do not enter a house in which there is a dog or a picture}}
\hadithdefcmd{nasai}{4283}{أَخْبَرَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ خَلِيٍّ، قَالَ حَدَّثَنَا بِشْرُ بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي ابْنُ السَّبَّاقِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَخْبَرَتْنِي مَيْمُونَةُ، زَوْجُ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَصْبَحَ يَوْمًا وَاجِمًا فَقَالَتْ لَهُ مَيْمُونَةُ أَىْ رَسُولَ اللَّهِ لَقَدِ اسْتَنْكَرْتُ هَيْئَتَكَ مُنْذُ الْيَوْمَ ‏.‏ فَقَالَ ‏"‏ إِنَّ جِبْرِيلَ عَلَيْهِ السَّلاَمُ كَانَ وَعَدَنِي أَنْ يَلْقَانِي اللَّيْلَةَ فَلَمْ يَلْقَنِي أَمَا وَاللَّهِ مَا أَخْلَفَنِي ‏"‏ ‏.‏ قَالَ فَظَلَّ يَوْمَهُ كَذَلِكَ ثُمَّ وَقَعَ فِي نَفْسِهِ جَرْوُ كَلْبٍ تَحْتَ نَضَدٍ لَنَا فَأَمَرَ بِهِ فَأُخْرِجَ ثُمَّ أَخَذَ بِيَدِهِ مَاءً فَنَضَحَ بِهِ مَكَانَهُ فَلَمَّا أَمْسَى لَقِيَهُ جِبْرِيلُ عَلَيْهِ السَّلاَمُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ كُنْتَ وَعَدْتَنِي أَنْ تَلْقَانِي الْبَارِحَةَ ‏"‏ ‏.‏ قَالَ أَجَلْ وَلَكِنَّا لاَ نَدْخُلُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ قَالَ فَأَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ ذَلِكَ الْيَوْمِ فَأَمَرَ بِقَتْلِ الْكِلاَبِ ‏.‏\hadithno{4283}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Maimunah, the wife of the Prophet narrated:"The Messenger of Allah was upset one morning and Maimunah said to him: "O Messenger of Allah, you look upset today., He said: 'Jibril, peace be upon him, had promised to meet me last night but he did not come, and by Allah, he never failed to keep an appointment,; The day passed, then he thought of a puppy that was beneath a table of ours. He ordered that it be taken out, and then he took some water In his hand and sprinkled it over the place where it had been. That evening, Jibril, peace be upon him, came and met him. The Messenger of Allah said to him: 'You [promised to meet me last night,; He said: 'Yes, but we do not enter a house in which there is a dog or a picture,; the next day the Messenger of Allah Commanded that dogs be killed]}}
\hadithdefcmd{nasai}{4284}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرِ بْنِ سُوَيْدٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، - وَهُوَ ابْنُ الْمُبَارَكِ - عَنْ حَنْظَلَةَ، قَالَ سَمِعْتُ سَالِمًا، يُحَدِّثُ عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اقْتَنَى كَلْبًا نَقَصَ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطَانِ إِلاَّ ضَارِيًا أَوْ صَاحِبَ مَاشِيَةٍ ‏"‏ ‏.‏\hadithno{4284}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn'Umar said:"The Messenger of Allah said: 'whoever keeps a dog, two Qirats will be detracted from his reward each day, except a trained hunting dog, or a dog for herding livestock}}
\hadithdefcmd{nasai}{4285}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرِ بْنِ إِيَاسِ بْنِ مُقَاتِلِ بْنِ مُشَمْرِجِ بْنِ خَالِدٍ السَّعْدِيُّ، عَنْ إِسْمَاعِيلَ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ يَزِيدَ، - وَهُوَ ابْنُ خُصَيْفَةَ - قَالَ أَخْبَرَنِي السَّائِبُ بْنُ يَزِيدَ، أَنَّهُ وَفَدَ عَلَيْهِمْ سُفْيَانُ بْنُ أَبِي زُهَيْرٍ الشَّنَائِيُّ وَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اقْتَنَى كَلْبًا لاَ يُغْنِي عَنْهُ زَرْعًا وَلاَ ضَرْعًا نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏ قُلْتُ يَا سُفْيَانُ أَنْتَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ وَرَبِّ هَذَا الْمَسْجِدِ ‏.‏\hadithno{4285}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{As-Saib bin Yazid narrated that Surfyan bin Abi Zuhair Ash-Shanai I came to visit them and said:"The Messenger of Allah said: 'Whoever keeps a dog which he does not need for farming or livestock, one Qirt will be deducted from his (good) deeds each day.' It was said to him: 'did you hear this from the Messenger of Allah He said: 'Yes, by the Lord of this Masjid}}
\hadithdefcmd{nasai}{4286}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ سَمِعَهُ يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَمْسَكَ كَلْبًا إِلاَّ كَلْبًا ضَارِيًا أَوْ كَلْبَ مَاشِيَةٍ نَقَصَ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطَانِ ‏"‏ ‏.‏\hadithno{4286}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said:' whoever keeps a dog except one that is trained for hunting or a dog for herding livestock, two Qirats will be deducted from his reward each day}}
\hadithdefcmd{nasai}{4287}{أَخْبَرَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اقْتَنَى كَلْبًا إِلاَّ كَلْبَ صَيْدٍ أَوْ مَاشِيَةٍ نَقَصَ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطَانِ ‏"‏ ‏.‏\hadithno{4287}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim, from his father, that the Messenger of Allah said:"Whoever keeps a dog. Except a dog for hunting or herding livestock, two Qirats will be deducted from his reward each day}}
\hadithdefcmd{nasai}{4288}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، وَابْنُ أَبِي عَدِيٍّ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ عَوْفٍ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اتَّخَذَ كَلْبًا إِلاَّ كَلْبَ صَيْدٍ أَوْ مَاشِيَةٍ أَوْ زَرْعٍ نَقَصَ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏\hadithno{4288}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Mughaffal that the Prophet said:"Whoever keeps a dog, except a dog for hunting, herding livestock or farming, one Qurat will be deducted from his reward each day}}
\hadithdefcmd{nasai}{4289}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اتَّخَذَ كَلْبًا إِلاَّ كَلْبَ صَيْدٍ أَوْ زَرْعٍ أَوْ مَاشِيَةٍ نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏\hadithno{4289}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Whoever keep s dog except a dog for hunting, farming or herding livestock, on e Qurat will be deducted from his good deeds each day}}
\hadithdefcmd{nasai}{4290}{أَخْبَرَنَا وَهْبُ بْنُ بَيَانٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، قَالَ أَنْبَأَنَا ابْنُ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اقْتَنَى كَلْبًا لَيْسَ بِكَلْبِ صَيْدٍ وَلاَ مَاشِيَةٍ وَلاَ أَرْضٍ فَإِنَّهُ يَنْقُصُ مِنْ أَجْرِهِ قِيرَاطَانِ كُلَّ يَوْمٍ ‏"‏ ‏.‏\hadithno{4290}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Whoever keeps a dog that is not a dog used for hunting, herding livestock or guarding land, two qirats will be deducted from his reward each day}}
\hadithdefcmd{nasai}{4291}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ جَعْفَرٍ - قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي حَرْمَلَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنِ اقْتَنَى كَلْبًا إِلاَّ كَلْبَ مَاشِيَةٍ أَوْ كَلْبَ صَيْدٍ نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ وَقَالَ أَبُو هُرَيْرَةَ ‏"‏ أَوْ كَلْبَ حَرْثٍ ‏"‏ ‏.‏\hadithno{4291}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim bin 'Abdullah that his father said:"The Messenger of Allah said: "Whoever keeps a dog, except a dog for herding livestock or a dog for hunting, one Qirat will be deducted from his reward each day." 'Abdullah said: "Abu Hurairah said: 'Or a dog for farming}}
\hadithdefcmd{nasai}{4292}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، أَنَّهُ سَمِعَ أَبَا مَسْعُودٍ، عُقْبَةَ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ثَمَنِ الْكَلْبِ وَمَهْرِ الْبَغِيِّ وَحُلْوَانِ الْكَاهِنِ ‏.‏\hadithno{4292}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Bakr bin 'Abdur-Rahman bin Al-Harith bin Hisham that her heard Abu Mas ud 'Uqbah say:"The Messenger of Allah forbade the price of a dog, the gift of a female fornicator and the fees of a fortuneteller."( Sahih)}}
\hadithdefcmd{nasai}{4293}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَنْبَأَنَا مَعْرُوفُ بْنُ سُوَيْدٍ الْجُذَامِيُّ، أَنَّ عُلَىَّ بْنَ رَبَاحٍ اللَّخْمِيَّ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ ثَمَنُ الْكَلْبِ وَلاَ حُلْوَانُ الْكَاهِنِ وَلاَ مَهْرُ الْبَغِيِّ ‏"‏ ‏.‏\hadithno{4293}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah said:"The Prophet said: 'The price of a dog, the fees of a fortuneteller and the gift of a female fornicator are not permissible}}
\hadithdefcmd{nasai}{4294}{أَخْبَرَنَا شُعَيْبُ بْنُ يُوسُفَ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ يُوسُفَ، عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ شَرُّ الْكَسْبِ مَهْرُ الْبَغِيِّ وَثَمَنُ الْكَلْبِ وَكَسْبُ الْحَجَّامِ ‏"‏ ‏.‏\hadithno{4294}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Waqi bin Khadij said:"The Messenger of Allah said: 'The worst of earnings arte the gift of a female fornicator, the price of a dog and the earnings of a cupper}}
\hadithdefcmd{nasai}{4295}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ الْمِقْسَمِيُّ، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ السِّنَّوْرِ وَالْكَلْبِ إِلاَّ كَلْبَ صَيْدٍ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَحَدِيثُ حَجَّاجٍ عَنْ حَمَّادِ بْنِ سَلَمَةَ لَيْسَ هُوَ بِصَحِيحٍ ‏.‏\hadithno{4295}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that:the Prophet forbade the price of cats and dogs, except hunting. (Da if) Abu Abdur-Rahman (An-Nasa I) said: The Hadith of Hajjaj from Hammad bin Salamah is not authentic:}}
\hadithdefcmd{nasai}{4296}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا ابْنُ سَوَاءٍ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ أَبِي مَالِكٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ لِي كِلاَبًا مُكَلَّبَةً فَأَفْتِنِي فِيهَا ‏.‏ قَالَ ‏"‏ مَا أَمْسَكَ عَلَيْكَ كِلاَبُكَ فَكُلْ ‏"‏ ‏.‏ قُلْتُ وَإِنْ قَتَلْنَ قَالَ ‏"‏ وَإِنْ قَتَلْنَ ‏"‏ ‏.‏ قَالَ أَفْتِنِي فِي قَوْسِي ‏.‏ قَالَ ‏"‏ مَا رَدَّ عَلَيْكَ سَهْمُكَ فَكُلْ ‏"‏ ‏.‏ قَالَ وَإِنْ تَغَيَّبَ عَلَىَّ قَالَ ‏"‏ وَإِنْ تَغَيَّبَ عَلَيْكَ مَا لَمْ تَجِدْ فِيهِ أَثَرَ سَهْمٍ غَيْرَ سَهْمِكَ أَوْ تَجِدْهُ قَدْ صَلَّ ‏"‏ ‏.‏ يَعْنِي قَدْ أَنْتَنَ ‏.‏ قَالَ ابْنُ سَوَاءٍ وَسَمِعْتُهُ مِنْ أَبِي مَالِكٍ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ عَنْ عَمْرِو بْنِ شُعَيْبٍ عَنْ أَبِيهِ عَنْ جَدِّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4296}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Arm bin Shu'aib, from his father, from his grandfather, that:a man came to the Prophet and said: "O Messenger of Allah, I have trained dogs; advise me concerning them." He said: "Whatever your dogs catch for you, eat," I side: "Even if they kill it?" He said: "Even if they kill it. " He said: "Advise me about my bow. "He said: "Whatever your arrow returns to you, eat." He said: "Even if it gets away from you, so long as you do not find the mark of an arrow other than yours on it, or you find that it has gone rotten."(Another chain)}}
\hadithdefcmd{nasai}{4297}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ بْنِ رَافِعٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ بَيْنَمَا نَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ذِي الْحُلَيْفَةِ مِنْ تِهَامَةَ فَأَصَابُوا إِبِلاً وَغَنَمًا وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي أُخْرَيَاتِ الْقَوْمِ فَعَجَّلَ أَوَّلُهُمْ فَذَبَحُوا وَنَصَبُوا الْقُدُورَ فَدُفِعَ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَمَرَ بِالْقُدُورِ فَأُكْفِئَتْ ثُمَّ قَسَّمَ بَيْنَهُمْ فَعَدَلَ عَشْرًا مِنَ الشَّاءِ بِبَعِيرٍ فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ نَدَّ بَعِيرٌ وَلَيْسَ فِي الْقَوْمِ إِلاَّ خَيْلٌ يَسِيرَةٌ فَطَلَبُوهُ فَأَعْيَاهُمْ فَرَمَاهُ رَجُلٌ بِسَهْمٍ فَحَبَسَهُ اللَّهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لِهَذِهِ الْبَهَائِمِ أَوَابِدَ كَأَوَابِدِ الْوَحْشِ فَمَا غَلَبَكُمْ مِنْهَا فَاصْنَعُوا بِهِ هَكَذَا ‏"‏ ‏.‏\hadithno{4297}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Rafi bin Khadij said:"While we were with the Messenger of Allah at Dhul-Hulaifah in Tihamanb, they acquired some camels and sheep (as spoils of war). The Messenger of Allah was among the last of the people, and the first of them hastened to slaughter (the animals) and set up pots (For cooking the meat). The Messenger of Allah came and ordered that the pots be came and ordered that the pots be overturned, then he divided it making ten sheep equivalent to one camel. While they were like that, a camel ran away. The people had only a few horses, so they went after fit and it and it got away from them. A man shot an arrow at it and stopped it. The Messenger of Allah said: 'Some of these animals arte untamed like wild animals, so if one of them goes out of your control, do the same}}
\hadithdefcmd{nasai}{4298}{أَخْبَرَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، قَالَ أَخْبَرَنِي عَاصِمٌ الأَحْوَلُ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّيْدِ فَقَالَ ‏ "‏ إِذَا رَمَيْتَ سَهْمَكَ فَاذْكُرِ اسْمَ اللَّهِ عَزَّ وَجَلَّ فَإِنْ وَجَدْتَهُ قَدْ قُتِلَ فَكُلْ إِلاَّ أَنْ تَجِدَهُ قَدْ وَقَعَ فِي مَاءٍ وَلاَ تَدْرِي الْمَاءُ قَتَلَهُ أَوْ سَهْمُكَ ‏"‏ ‏.‏\hadithno{4298}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"I asked the Messenger of Allah about hunting and he said: 'When you shoot your arrow, mention the name of Allah, and if you find that it (the game) has been killed, the eat it, unless you find that it fell into some water, and you do not know whether the water killed it or your arrow}}
\hadithdefcmd{nasai}{4299}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ، قَالَ حَدَّثَنَا مُوسَى بْنُ أَعْيَنَ، عَنْ مَعْمَرٍ، عَنْ عَاصِمِ بْنِ سُلَيْمَانَ، عَنْ عَامِرٍ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّيْدِ فَقَالَ ‏"‏ إِذَا أَرْسَلْتَ سَهْمَكَ وَكَلْبَكَ وَذَكَرْتَ اسْمَ اللَّهِ فَقَتَلَ سَهْمُكَ فَكُلْ ‏"‏ ‏.‏ قَالَ فَإِنْ بَاتَ عَنِّي لَيْلَةً يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِنْ وَجَدْتَ سَهْمَكَ وَلَمْ تَجِدْ فِيهِ أَثَرَ شَىْءٍ غَيْرَهُ فَكُلْ وَإِنْ وَقَعَ فِي الْمَاءِ فَلاَ تَأْكُلْ ‏"‏ ‏.‏\hadithno{4299}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Adiyy bin Hatim that he asked the Messenger of Allah about hunting and he said:"When you release your arrow or your dog, mention the name of Allah, and when your arrow kills (the game), then eat." He said: "What if it gets away from me for a night, O Messenger of Allah?" He said: "If you find your arrow and you do not find the mark of anything else, then eat it. But if it falls into the water, do not eat it}}
\hadithdefcmd{nasai}{4300}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا أَهْلُ الصَّيْدِ وَإِنَّ أَحَدَنَا يَرْمِي الصَّيْدَ فَيَغِيبُ عَنْهُ اللَّيْلَةَ وَاللَّيْلَتَيْنِ فَيَبْتَغِي الأَثَرَ فَيَجِدُهُ مَيِّتًا وَسَهْمُهُ فِيهِ ‏.‏ قَالَ ‏ "‏ إِذَا وَجَدْتَ السَّهْمَ فِيهِ وَلَمْ تَجِدْ فِيهِ أَثَرَ سَبُعٍ وَعَلِمْتَ أَنَّ سَهْمَكَ قَتَلَهُ فَكُلْ ‏"‏ ‏.‏\hadithno{4300}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated tht 'Adiyy bin Hatim said:"I said: 'O Messenger of Allah, we are a people who hunt, and one of us may shoot his arrow but (the game) gets way from him for a night or two. What if he follows its tracks, and finds it dead with his arrow in it?" He said: "If you find the arrow in it, and you do not find any sign of predators, and you know that your arrow killed it, then eat it." (Sahih)}}
\hadithdefcmd{nasai}{4301}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، وَإِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالاَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَيْتَ سَهْمَكَ فِيهِ وَلَمْ تَرَ فِيهِ أَثَرًا غَيْرَهُ وَعَلِمْتَ أَنَّهُ قَتَلَهُ فَكُلْ ‏"‏ ‏.‏\hadithno{4301}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Adiyy bin Hatim that the Messenger of Allah said:"If you see your arrow in it. And you do not see any other mark, and you know that (Your arrow) killed it, then eat it}}
\hadithdefcmd{nasai}{4302}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ مَيْسَرَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَرْمِي الصَّيْدَ فَأَطْلُبُ أَثَرَهُ بَعْدَ لَيْلَةٍ ‏.‏ قَالَ ‏ "‏ إِذَا وَجَدْتَ فِيهِ سَهْمَكَ وَلَمْ يَأْكُلْ مِنْهُ سَبُعٌ فَكُلْ ‏"‏ ‏.‏\hadithno{4302}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{it was narrated that 'Adiyy bin Hatim said:"I said: 'O Messenger of Allah, I shoot game and I follow its tracks after of night. He said: 'If you find your arrow in it, and no predator has eaten from it, then eat it}}
\hadithdefcmd{nasai}{4303}{أَخْبَرَنِي أَحْمَدُ بْنُ خَالِدٍ الْخَلاَّلُ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ أَنْبَأَنَا مُعَاوِيَةُ، - وَهُوَ ابْنُ صَالِحٍ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ أَبِي ثَعْلَبَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الَّذِي يُدْرِكُ صَيْدَهُ بَعْدَ ثَلاَثٍ فَلْيَأْكُلْهُ إِلاَّ أَنْ يُنْتِنَ ‏.‏\hadithno{4303}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Tha'labah from the Prophet that:the one who catches up with the game (he shot) after three days may eat from it, unless it has turned rotten}}
\hadithdefcmd{nasai}{4304}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ سِمَاكٍ، قَالَ سَمِعْتُ مُرِّيَّ بْنَ قَطَرِيٍّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أُرْسِلُ كَلْبِي فَيَأْخُذُ الصَّيْدَ وَلاَ أَجِدُ مَا أُذَكِّيهِ بِهِ فَأُذَكِّيهِ بِالْمَرْوَةِ وَالْعَصَا ‏.‏ قَالَ ‏ "‏ أَهْرِقِ الدَّمَ بِمَا شِئْتَ وَاذْكُرِ اسْمَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4304}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{t was narrated that 'Adiyy bin Hatim said:"I said: 'O Messenger of Allah, I release my dog and he catches the game, but I cannot find anything with which to slaughter it, so I slaughter it with a sharp-edged stone or a stick.' He said: 'Shed the blood with whatever you want, and mention the name of Allah}}
\hadithdefcmd{nasai}{4305}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أُرْسِلُ الْكِلاَبَ الْمُعَلَّمَةَ فَتُمْسِكُ عَلَىَّ فَآكُلُ مِنْهُ قَالَ ‏"‏ إِذَا أَرْسَلْتَ الْكِلاَبَ - يَعْنِي الْمُعَلَّمَةَ - وَذَكَرْتَ اسْمَ اللَّهِ فَأَمْسَكْنَ عَلَيْكَ فَكُلْ ‏"‏ ‏.‏ قُلْتُ وَإِنْ قَتَلْنَ قَالَ ‏"‏ وَإِنْ قَتَلْنَ مَا لَمْ يَشْرَكْهَا كَلْبٌ لَيْسَ مِنْهَا ‏"‏ ‏.‏ قُلْتُ وَإِنِّي أَرْمِي الصَّيْدَ بِالْمِعْرَاضِ فَأُصِيبُ فَآكُلُ قَالَ ‏"‏ إِذَا رَمَيْتَ بِالْمِعْرَاضِ وَسَمَّيْتَ فَخَزَقَ فَكُلْ وَإِذَا أَصَابَ بِعَرْضِهِ فَلاَ تَأْكُلْ ‏"‏ ‏.‏\hadithno{4305}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{t was narrated that 'Adiyy bin Hatim said:"I said: 'O Messenger of Allah, I release my trained dogs and they catch (the game) for me - should I eat of it?" he said: 'If you release your trained dogs, and mention the name of Allah, and they catch it for your, then eat.' I said: 'Even if they kill it?' He said:" 'Even if they kill it, so long as another, strange dog has not joined them 'I said: 'And I shoot the game with the Mirad and I hit it - should I eat?' He said: ''If you shoot the and it penetrates (the target), then eat, but if it hits it with its broad edge, then do not6 eat it}}
\hadithdefcmd{nasai}{4306}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، قَالَ سَمِعْتُ عَدِيَّ بْنَ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمِعْرَاضِ فَقَالَ ‏ "‏ إِذَا أَصَابَ بِحَدِّهِ فَكُلْ وَإِذَا أَصَابَ بِعَرْضِهِ فَقُتِلَ فَإِنَّهُ وَقِيذٌ فَلاَ تَأْكُلْ ‏"‏ ‏.‏\hadithno{4306}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{(It was narrated that Ash-Sha bi said:" I heard 'Adiyy bin Hatim say: 'I asked the Messenger of Allah about the Mirad and he said: "If the sharp point hits 9the game) then eat, bu}}
\hadithdefcmd{nasai}{4307}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ الذَّارِعُ، قَالَ حَدَّثَنَا أَبُو مِحْصَنٍ، قَالَ حَدَّثَنَا حُصَيْنٌ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَيْدِ الْمِعْرَاضِ فَقَالَ ‏ "‏ إِذَا أَصَابَ بِحَدِّهِ فَكُلْ وَإِذَا أَصَابَ بِعَرْضِهِ فَلاَ تَأْكُلْ ‏"‏ ‏.‏\hadithno{4307}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"I asked the Messenger of Allah about hunting with the Mirad and the said: 'If the sharp edge hits (the game), then eat, but if the broad edge of it strikes it, do not eat it}}
\hadithdefcmd{nasai}{4308}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا عِيسَى بْنُ يُونُسَ، وَغَيْرُهُ، عَنْ زَكَرِيَّا، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَيْدِ الْمِعْرَاضِ فَقَالَ ‏ "‏ مَا أَصَبْتَ بِحَدِّهِ فَكُلْ وَمَا أَصَابَ بِعَرْضِهِ فَهُوَ وَقِيذٌ ‏"‏ ‏.‏\hadithno{4308}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Adiyy bin Htim said:"I asked the Messenger of Allah about hunting with Mirad and he said: 'If the sharp edge hits (the game), then eat, but if the broad edge of it strikes it, then it has been killed by a blow}}
\hadithdefcmd{nasai}{4309}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ أَبِي مُوسَى، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي مُوسَى، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ سَكَنَ الْبَادِيَةَ جَفَا وَمَنِ اتَّبَعَ الصَّيْدَ غَفُلَ وَمَنِ اتَّبَعَ السُّلْطَانَ افْتُتِنَ ‏"‏ ‏.‏ وَاللَّفْظُ لاِبْنِ الْمُثَنَّى ‏.‏\hadithno{4309}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet said:"Whoever lives in the desert, he becomes hard-hearted, and whoever follows game becomes preoccupied with it (and neglectful toward other duties), and whoever follows the ruler will put himself through trial."(Sahih) The wording is of Ibn Al-Muthanna}}
\hadithdefcmd{nasai}{4310}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ الْبَحْرَانِيُّ، قَالَ حَدَّثَنَا حَبَّانُ، - وَهُوَ ابْنُ هِلاَلٍ قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم بِأَرْنَبٍ قَدْ شَوَاهَا فَوَضَعَهَا بَيْنَ يَدَيْهِ فَأَمْسَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يَأْكُلْ وَأَمَرَ الْقَوْمَ أَنْ يَأْكُلُوا وَأَمْسَكَ الأَعْرَابِيُّ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا يَمْنَعُكَ أَنْ تَأْكُلَ ‏"‏ ‏.‏ قَالَ إِنِّي أَصُومُ ثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏.‏ قَالَ ‏"‏ إِنْ كُنْتَ صَائِمًا فَصُمِ الْغُرَّ ‏"‏ ‏.‏\hadithno{4310}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"A Bedouin brought a rabbit to the Messenger of Allah that he had grilled and placed it before him. The messenger of Allah refrained from eating but he told the people to eat. The Bedouin also refrained from eating, and the Messenger of Allah said to him: 'What is keeping you from eating?' He said: 'I fast three days of each month.' He Said: "If you are going to fast, then fast the bright days (Al-Ghurr)}}
\hadithdefcmd{nasai}{4311}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ حَكِيمِ بْنِ جُبَيْرٍ، وَعَمْرِو بْنِ عُثْمَانَ، وَمُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنِ ابْنِ الْحَوْتَكِيَّةِ، قَالَ قَالَ عُمَرُ رضى الله عنه مَنْ حَاضِرُنَا يَوْمَ الْقَاحَةِ قَالَ قَالَ أَبُو ذَرٍّ أَنَا أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِأَرْنَبٍ فَقَالَ الرَّجُلُ الَّذِي جَاءَ بِهَا إِنِّي رَأَيْتُهَا تَدْمَى ‏.‏ فَكَانَ النَّبِيُّ صلى الله عليه وسلم لَمْ يَأْكُلْ ثُمَّ إِنَّهُ قَالَ ‏"‏ كُلُوا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ إِنِّي صَائِمٌ ‏.‏ قَالَ ‏"‏ وَمَا صَوْمُكَ ‏"‏ ‏.‏ قَالَ مِنْ كُلِّ شَهْرٍ ثَلاَثَةُ أَيَّامٍ ‏.‏ قَالَ ‏"‏ فَأَيْنَ أَنْتَ عَنِ الْبِيضِ الْغُرِّ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏"‏ ‏.‏\hadithno{4311}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Al- Hawtakiyyah said:"Umar, May Allah be pleased with us on the day when we stopped at Al-Qaha?' Abu Dharr said: 'I was. A rabbit was brought to the Messenger Allah and the man who brought it said: I saw it bleeding (menstruating). The Prophet did not eat, then he said: "Eat." A man said: "I am fasting." He said: "What fast are you observing?" He said: "Three days each month" He said: "Why don't yo}}
\hadithdefcmd{nasai}{4312}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ هِشَامٍ، - وَهُوَ ابْنُ زَيْدٍ - قَالَ سَمِعْتُ أَنَسًا، يَقُولُ أَنْفَجْنَا أَرْنَبًا بِمَرِّ الظَّهْرَانِ فَأَخَذْتُهَا فَجِئْتُ بِهَا إِلَى أَبِي طَلْحَةَ فَذَبَحَهَا فَبَعَثَنِي بِفَخِذَيْهَا وَوَرِكَيْهَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَبِلَهُ ‏.‏\hadithno{4312}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas said:"We disturbed a rabbit in Marr Az-Zahran so I caught it, and brought it to Abu Talhah who slaughtered it, and sent me with its thighs and haunches to the Prophet and he accepted it}}
\hadithdefcmd{nasai}{4313}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَفْصٌ، عَنْ عَاصِمٍ، وَدَاوُدَ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ صَفْوَانَ، قَالَ أَصَبْتُ أَرْنَبَيْنِ فَلَمْ أَجِدْ مَا أُذَكِّيهِمَا بِهِ فَذَكَّيْتُهُمَا بِمَرْوَةٍ فَسَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَمَرَنِي بِأَكْلِهِمَا ‏.‏\hadithno{4313}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn Safwan said:"I caught two rabbits but I could not find anything with which to slaughter then, so I slaughtered them with a sharp-edged stone. I asked the Prophet about that and he commanded me to eat them}}
\hadithdefcmd{nasai}{4314}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ سُئِلَ عَنِ الضَّبِّ فَقَالَ ‏ "‏ لاَ آكُلُهُ وَلاَ أُحَرِّمُهُ ‏"‏ ‏.‏\hadithno{4314}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah was asked about mastigures when he was on the Minbar and he said? "I do not eat them, but I do not say that they are Haram}}
\hadithdefcmd{nasai}{4315}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ مَا تَرَى فِي الضَّبِّ قَالَ ‏ "‏ لَسْتُ بِآكِلِهِ وَلاَ مُحَرِّمِهِ ‏"‏ ‏.‏\hadithno{4315}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Umar that a man said:"O Messenger of Allah what do you think about mastigures?" He said: "I do not eat them but I do not say that they arte Haram}}
\hadithdefcmd{nasai}{4316}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، عَنْ مُحَمَّدِ بْنِ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، قَالَ أَخْبَرَنِي الزُّهْرِيُّ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ خَالِدِ بْنِ الْوَلِيدِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِضَبٍّ مَشْوِيٍّ فَقُرِّبَ إِلَيْهِ فَأَهْوَى إِلَيْهِ بِيَدِهِ لِيَأْكُلَ مِنْهُ قَالَ لَهُ مَنْ حَضَرَ يَا رَسُولَ اللَّهِ إِنَّهُ لَحْمُ ضَبٍّ ‏.‏ فَرَفَعَ يَدَهُ عَنْهُ فَقَالَ لَهُ خَالِدُ بْنُ الْوَلِيدِ يَا رَسُولَ اللَّهِ أَحَرَامٌ الضَّبُّ قَالَ ‏ "‏ لاَ وَلَكِنْ لَمْ يَكُنْ بِأَرْضِ قَوْمِي فَأَجِدُنِي أَعَافُهُ ‏"‏ ‏.‏ فَأَهْوَى خَالِدٌ إِلَى الضَّبِّ فَأَكَلَ مِنْهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَنْظُرُ ‏.‏\hadithno{4316}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Khalid bin Al-Walid that:A grilled mastigure was brought to the Messenger of Allah and was placed near to him. He reached out his hand to eat it, and someone who was present said: "O Messenger of Allah, it is the meat of a mastigure." He withdrew his hand and Khalid bin Al-Walid said to him: "O Messenger of Allah, is mastigure Haram?" He said: "No, but it is not found in the land of my people, and I find it distasteful." He said: "Then Khalid bent over the mastigure and ate some of it, and the Messenger of Allah was looking at him}}
\hadithdefcmd{nasai}{4317}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ أَخْبَرَهُ أَنَّ خَالِدَ بْنَ الْوَلِيدِ أَخْبَرَهُ أَنَّهُ، دَخَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى مَيْمُونَةَ بِنْتِ الْحَارِثِ - وَهِيَ خَالَتُهُ - فَقُدِّمَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَحْمُ ضَبٍّ - وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَأْكُلُ شَيْئًا حَتَّى يَعْلَمَ مَا هُوَ - فَقَالَ بَعْضُ النِّسْوَةِ أَلاَ تُخْبِرْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا يَأْكُلُ فَأَخْبَرَتْهُ أَنَّهُ لَحْمُ ضَبٍّ فَتَرَكَهُ قَالَ خَالِدٌ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَحَرَامٌ هُوَ قَالَ ‏ "‏ لاَ وَلَكِنَّهُ طَعَامٌ لَيْسَ فِي أَرْضِ قَوْمِي فَأَجِدُنِي أَعَافُهُ ‏"‏ ‏.‏ قَالَ خَالِدٌ فَاجْتَرَرْتُهُ إِلَىَّ فَأَكَلْتُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَنْظُرُ ‏.‏ وَحَدَّثَهُ ابْنُ الأَصَمِّ عَنْ مَيْمُونَةَ وَكَانَ فِي حَجْرِهَا ‏.‏\hadithno{4317}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ' Abbas that:Khalid bin Al-Walid said that he entered upon Maimunah bint Al-Harith, who was his maternal aunt, with the Messenger of Allah, and some meat of a mastigure was offered to the Messenger of Allah The Messenger of Allah would not eat anything until he knew what it was. One of the women said: "Why don't you tell the Messenger of Allah what he is eating?" So she told him that it was the meat of a mastigure, and he stopped eating. Khalid said: "I asked the Messenger of Allah 'Is it Haram?' He said: "No but it is a food that is no}}
\hadithdefcmd{nasai}{4318}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَهْدَتْ خَالَتِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَقِطًا وَسَمْنًا وَأَضُبًّا فَأَكَلَ مِنَ الأَقِطِ وَالسَّمْنِ وَتَرَكَ الأَضُبَّ تَقَذُّرًا وَأُكِلَ عَلَى مَائِدَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَوْ كَانَ حَرَامًا مَا أُكِلَ عَلَى مَائِدَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4318}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"My maternal aunt gave some cottage cheese, cooking fat, and mastigures to the Messenger of Allah He ate some of the cottage cheese and cooking fat, and left the mastigures, as he found them distasteful. But they were eaten upon the table-spread of the Messenger of Allah and if they were Haram they would not have been eaten upon the table-spread of the Messenger of Allah and he would not have told others to eat them}}
\hadithdefcmd{nasai}{4319}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ سُئِلَ عَنْ أَكْلِ الضِّبَابِ، فَقَالَ أَهْدَتْ أُمُّ حُفَيْدٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم سَمْنًا وَأَقِطًا وَأَضُبًّا فَأَكَلَ مِنَ السَّمْنِ وَالأَقِطِ وَتَرَكَ الضِّبَابَ تَقَذُّرًا لَهُنَّ فَلَوْ كَانَ حَرَامًا مَا أُكِلَ عَلَى مَائِدَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ أَمَرَ بِأَكْلِهِنَّ ‏.‏\hadithno{4319}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:he was asked about eating mastigures. He said: "Umm Hufaid gave some cooking fat, cottage cheese, and mastigures to the Messenger of Allah and the ate some of the cooking fat and cottage cheese, but he did not eat the mastigures because he found them distasteful. If they were Haram they would not have been eaten at the table-spread of the Messenger of Allah and the would not have told others to eat them}}
\hadithdefcmd{nasai}{4320}{أَخْبَرَنَا سُلَيْمَانُ بْنُ مَنْصُورٍ الْبَلْخِيُّ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، سَلاَّمُ بْنُ سُلَيْمٍ عَنْ حُصَيْنٍ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ ثَابِتِ بْنِ يَزِيدَ الأَنْصَارِيِّ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَنَزَلْنَا مَنْزِلاً فَأَصَابَ النَّاسُ ضِبَابًا فَأَخَذْتُ ضَبًّا فَشَوَيْتُهُ ثُمَّ أَتَيْتُ بِهِ النَّبِيَّ صلى الله عليه وسلم فَأَخَذَ عُودًا يَعُدُّ بِهِ أَصَابِعَهُ ثُمَّ قَالَ ‏ "‏ إِنَّ أُمَّةً مِنْ بَنِي إِسْرَائِيلَ مُسِخَتْ دَوَابَّ فِي الأَرْضِ وَإِنِّي لاَ أَدْرِي أَىُّ الدَّوَابِّ هِيَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ النَّاسَ قَدْ أَكَلُوا مِنْهَا - قَالَ - فَمَا أَمَرَ بِأَكْلِهَا وَلاَ نَهَى ‏.‏\hadithno{4320}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Thabit bin Yazid Al-Ansari said:"We were with the Prophet on a journey. We stopped to camp and the people caught some mastigures. I took a mastigure and grilled it, and brought it to the Prophet. He took a palm stalk, and started counting his fingers with it, and said: 'A nation from among the children of Israel was turned into beasts of the Earth, and I do not know what kind of animals they were, I said: 'O Messenger of Allah, the people have eaten some of them.' He did not tell them to eat it, and he did not forbid them from eating it}}
\hadithdefcmd{nasai}{4321}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي عَدِيُّ بْنُ ثَابِتٍ، قَالَ سَمِعْتُ زَيْدَ بْنَ وَهْبٍ، يُحَدِّثُ عَنْ ثَابِتِ بْنِ وَدِيعَةَ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِضَبٍّ فَجَعَلَ يَنْظُرُ إِلَيْهِ وَيُقَلِّبُهُ وَقَالَ ‏ "‏ إِنَّ أُمَّةً مُسِخَتْ لاَ يُدْرَى مَا فَعَلَتْ وَإِنِّي لاَ أَدْرِي لَعَلَّ هَذَا مِنْهَا ‏"‏ ‏.‏\hadithno{4321}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Thabit bin Wadi ah said:"A man brought a mastigure to the Messenger of Allah and he started looking at it, and turning it over. He said: 'A nation was transformed, it is not known what they did, and I do not know if this is one of them}}
\hadithdefcmd{nasai}{4322}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، عَنْ ثَابِتِ بْنِ وَدِيعَةَ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم بِضَبٍّ فَقَالَ ‏ "‏ إِنَّ أُمَّةً مُسِخَتْ وَاللَّهُ أَعْلَمُ ‏"‏ ‏.‏\hadithno{4322}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from al-Bara bin Azib, from Thabnit bin Wadiah, that:a man brought a mastigure to the Prophet and he said? "A nation was transformed, and Allah knows best}}
\hadithdefcmd{nasai}{4323}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي ابْنُ جُرَيْجٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنِ ابْنِ أَبِي عَمَّارٍ، قَالَ سَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ عَنِ الضَّبُعِ، فَأَمَرَنِي بِأَكْلِهَا فَقُلْتُ أَصَيْدٌ هِيَ قَالَ نَعَمْ ‏.‏ قُلْتُ أَسَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏\hadithno{4323}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Abi 'Ammar said:"I asked Jabir bin 'Abdullah about hyenas and he told me to eat them. I said: 'Are they game (that can be hunted)? He said: 'Yes,' I said: 'Did you hear that from the Messenger of Allah?' He said: 'Yes}}
\hadithdefcmd{nasai}{4324}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَكِيمٍ، عَنْ عَبِيدَةَ بْنِ سُفْيَانَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ ذِي نَابٍ مِنَ السِّبَاعِ فَأَكْلُهُ حَرَامٌ ‏"‏ ‏.‏\hadithno{4324}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the prophet said:'Every predator possessing fangs is forbidden to eat}}
\hadithdefcmd{nasai}{4325}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ ‏.‏\hadithno{4325}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Tha labah Al-Khushani that:the Prophet forbade eating any predator that has fangs}}
\hadithdefcmd{nasai}{4326}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، عَنْ خَالِدٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِي ثَعْلَبَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحِلُّ النُّهْبَى وَلاَ يَحِلُّ مِنَ السِّبَاعِ كُلُّ ذِي نَابٍ وَلاَ تَحِلُّ الْمُجْثَّمَةُ ‏"‏ ‏.‏\hadithno{4326}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Tha'labah said:"The Messenger of Allah said: 'Wealth taken by force is (not permissible), any predator that has fangs is not permissible, and any animal used for target practice is not permissible}}
\hadithdefcmd{nasai}{4327}{أَخْبَرَنَا قُتَيْبَةُ، وَأَحْمَدُ بْنُ عَبْدَةَ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، - وَهُوَ ابْنُ دِينَارٍ - عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ جَابِرٍ، قَالَ نَهَى - وَذَكَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم - يَوْمَ خَيْبَرَ عَنْ لُحُومِ الْحُمُرِ وَأَذِنَ فِي الْخَيْلِ ‏.‏\hadithno{4327}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir said:"On the Day of Khaibar, the Messenger of Allah forbade the flesh of donkeys but he permitted the flesh of horses}}
\hadithdefcmd{nasai}{4328}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، قَالَ أَطْعَمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم لُحُومَ الْخَيْلِ وَنَهَانَا عَنْ لُحُومِ الْحُمُرِ ‏.‏\hadithno{4328}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah allowed us to eat the flesh of horses but he forbade the flesh of donkeys}}
\hadithdefcmd{nasai}{4329}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ، - وَهُوَ ابْنُ وَاقِدٍ - عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، وَعَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرٍ، وَعَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ أَطْعَمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ خَيْبَرَ لُحُومَ الْخَيْلِ وَنَهَانَا عَنْ لُحُومِ الْحُمُرِ ‏.‏\hadithno{4329}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:" On the Day of Khaibar, the Messenger of Allah (ﷺ) allowed us to eat the flesh of horses but he forbade us from the flesh of donkeys}}
\hadithdefcmd{nasai}{4330}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، - وَهُوَ ابْنُ عَمْرٍو - قَالَ حَدَّثَنَا عَبْدُ الْكَرِيمِ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَأْكُلُ لُحُومَ الْخَيْلِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4330}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir said:"We used to eat horse meat during the time of the Messenger of Allah}}
\hadithdefcmd{nasai}{4331}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، قَالَ حَدَّثَنِي ثَوْرُ بْنُ يَزِيدَ، عَنْ صَالِحِ بْنِ يَحْيَى بْنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ خَالِدِ بْنِ الْوَلِيدِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ أَكْلُ لُحُومِ الْخَيْلِ وَالْبِغَالِ وَالْحَمِيرِ ‏"‏ ‏.‏\hadithno{4331}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Khalid bin al-walid that he heard the Messe4nger of Allah say:"It is not permissible to eat the flesh of horses, mules or donkeys}}
\hadithdefcmd{nasai}{4332}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ صَالِحِ بْنِ يَحْيَى بْنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ خَالِدِ بْنِ الْوَلِيدِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ لُحُومِ الْخَيْلِ وَالْبِغَالِ وَالْحَمِيرِ وَكُلِّ ذِي نَابٍ مِنَ السِّبَاعِ ‏.‏\hadithno{4332}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Khalid bin Al-Walid that:the Messenger of Allah forbade eating the flesh of horses, mules and donkeys, and any predator that has fangs}}
\hadithdefcmd{nasai}{4333}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَأْكُلُ لُحُومَ الْخَيْلِ ‏.‏ قُلْتُ الْبِغَالَ قَالَ لاَ ‏.‏\hadithno{4333}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ata, that Jabir said:"we used to eat horseflesh. ": I said: "And mules?" He said: "No}}
\hadithdefcmd{nasai}{4334}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنِ الْحَسَنِ بْنِ مُحَمَّدٍ، وَعَبْدِ اللَّهِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِمَا، قَالَ قَالَ عَلِيٌّ لاِبْنِ عَبَّاسٍ رضى الله عنهما إِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ نِكَاحِ الْمُتْعَةِ وَعَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ يَوْمَ خَيْبَرَ ‏.‏\hadithno{4334}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Al- Hasan bin Muhammad, and 'Abdullah bin Muhammad that their father said:"Ali said to Ibn'Abbas, may Allah be please with them both: The Prophet forbade Mut'ah marriage, and the flesh of domesticated donkeys on the Day of Khaibar}}
\hadithdefcmd{nasai}{4335}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، وَمَالِكٌ، وَأُسَامَةُ، عَنِ ابْنِ شِهَابٍ، عَنِ الْحَسَنِ، وَعَبْدِ اللَّهِ، ابْنَىْ مُحَمَّدٍ عَنْ أَبِيهِمَا، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عنه قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ مُتْعَةِ النِّسَاءِ يَوْمَ خَيْبَرَ وَعَنْ لُحُومِ الْحُمُرِ الإِنْسِيَّةِ ‏.‏\hadithno{4335}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Al-Hasan bin Muhammad, and 'Abdullah bin Muhammad, from their father, that 'Ali bin Abi Talib may Allah be please with him, said:"The Messenger of Allah forbade Mut'ah and the flesh of domesticated donkeys on the Day of Khaibar}}
\hadithdefcmd{nasai}{4336}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ أَنْبَأَنَا عُبَيْدُ اللَّهِ، ح وَأَنْبَأَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْحُمُرِ الأَهْلِيَّةِ يَوْمَ خَيْبَرَ ‏.‏\hadithno{4336}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah forbade (the flesh of) domesticated donkeys on the Day of Khaibar}}
\hadithdefcmd{nasai}{4337}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مِثْلَهُ وَلَمْ يَقُلْ خَيْبَرَ ‏.‏\hadithno{4337}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated from Ibn 'Umar:A similar report was narrated from Ibn 'Umar, but he did not mention Khaibar}}
\hadithdefcmd{nasai}{4338}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ خَيْبَرَ عَنْ لُحُومِ الْحُمُرِ الإِنْسِيَّةِ نَضِيجًا وَنِيئًا ‏.‏\hadithno{4338}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Al-Bara said:"On the Day of Khaibar, the Messenger of Allah forbade the flesh of domesticated donkeys, cooked or raw}}
\hadithdefcmd{nasai}{4339}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ أَصَبْنَا يَوْمَ خَيْبَرَ حُمُرًا خَارِجًا مِنَ الْقَرْيَةِ فَطَبَخْنَاهَا فَنَادَى مُنَادِي النَّبِيِّ صلى الله عليه وسلم إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ حَرَّمَ لُحُومَ الْحُمُرِ فَأَكْفِئُوا الْقُدُورَ بِمَا فِيهَا ‏.‏ فَأَكْفَأْنَاهَا ‏.‏\hadithno{4339}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin Awfa said:"On the Day of khaiber we caught some donkeys outside the village and we cooked them. Then the caller of the Prophet called out: 'The Messenger of Allah has forbidden the flesh of donkeys, so turn over your cooking pots with whatever is in them.' So we turned them over}}
\hadithdefcmd{nasai}{4340}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ، قَالَ صَبَّحَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ فَخَرَجُوا إِلَيْنَا وَمَعَهُمُ الْمَسَاحِي فَلَمَّا رَأَوْنَا قَالُوا مُحَمَّدٌ وَالْخَمِيسُ ‏.‏ وَرَجَعُوا إِلَى الْحِصْنِ يَسْعَوْنَ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ ثُمَّ قَالَ ‏ "‏ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ خَرِبَتْ خَيْبَرُ إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏ ‏.‏ فَأَصَبْنَا فِيهَا حُمُرًا فَطَبَخْنَاهَا فَنَادَى مُنَادِي النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ اللَّهَ عَزَّ وَجَلَّ وَرَسُولَهُ يَنْهَاكُمْ عَنْ لُحُومِ الْحُمُرِ فَإِنَّهَا رِجْسٌ ‏.‏\hadithno{4340}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah reached Khaibar in the morning, and they came out to us carrying their shovels. When they saw us they said: 'Muhammad and the army!' And they rushed back inot the fortress. The Messenger of Allah raised his hands, then he said: ' Allahu Akbar, Allahu Akbar, Khaibar is destroyed. Verily, when we descend in field of a people (i.e. near to them), evil will be the morning for those who had been warned! Acquired some donkeys there and we cooked the., Then the caller of the Prophet called out: 'Allah and His Messenger forbid you to eat the flesh of donkeys, for it is an abomination}}
\hadithdefcmd{nasai}{4341}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، أَنْبَأَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، أَنَّهُ حَدَّثَهُمْ أَنَّهُمْ، غَزَوْا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى خَيْبَرَ وَالنَّاسُ جِيَاعٌ فَوَجَدُوا فِيهَا حُمُرًا مِنْ حُمُرِ الإِنْسِ فَذَبَحَ النَّاسُ مِنْهَا فَحُدِّثَ بِذَلِكَ النَّبِيُّ صلى الله عليه وسلم فَأَمَرَ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ فَأَذَّنَ فِي النَّاسِ ‏ "‏ أَلاَ إِنَّ لُحُومَ الْحُمُرِ الإِنْسِ لاَ تَحِلُّ لِمَنْ يَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏\hadithno{4341}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Tha''Aabah Al-Khushani that:they went on a military campaign with the Messenger of Allah to Khaibar, and the people were starving. They found some domesticated donkeys there, so the people slaughtered some of them. The Prophet was told about that, and he ordered 'Abdur-rahman bin 'Awf to announce to the people: "The flesh of domesticated donkeys is not permissible for the one who testifies that I am the Messenger of Allah}}
\hadithdefcmd{nasai}{4342}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، عَنْ بَقِيَّةَ، قَالَ حَدَّثَنِي الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ وَعَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ ‏.‏\hadithno{4342}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Tha'labah Al-khushani that:the Messenger of Allah forbade eating any -predator with fangs, and the flesh of domesticated donkeys}}
\hadithdefcmd{nasai}{4343}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْمُفَضَّلُ، - هُوَ ابْنُ فَضَالَةَ - عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَكَلْنَا يَوْمَ خَيْبَرَ لُحُومَ الْخَيْلِ وَالْوَحْشِ وَنَهَانَا النَّبِيُّ صلى الله عليه وسلم عَنِ الْحِمَارِ ‏.‏\hadithno{4343}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"On the Day of Khaibar we ate the flesh of horses, and onagers, but the Prophet forbade us (from eating) donkeys."(sahih)}}
\hadithdefcmd{nasai}{4344}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا بَكْرٌ، - هُوَ ابْنُ مُضَرَ - عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ عُمَيْرِ بْنِ سَلَمَةَ الضَّمْرِيِّ، قَالَ بَيْنَا نَحْنُ نَسِيرُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِبَعْضِ أَثَايَا الرَّوْحَاءِ وَهُمْ حُرُمٌ إِذَا حِمَارُ وَحْشٍ مَعْقُورٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعُوهُ فَيُوشِكُ صَاحِبُهُ أَنْ يَأْتِيَهُ ‏"‏ ‏.‏ فَجَاءَ رَجُلٌ مِنْ بَهْزٍ هُوَ الَّذِي عَقَرَ الْحِمَارَ فَقَالَ يَا رَسُولَ اللَّهِ شَأْنَكُمْ هَذَا الْحِمَارُ ‏.‏ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا بَكْرٍ يُقَسِّمُهُ بَيْنَ النَّاسِ ‏.‏\hadithno{4344}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Umair bin Salamah Ad-Damri said:"While we were traveling with the Prophet in part of Athaya Ar-Rawha and they were in Ihram, we saw a wounded onager, the Messenger of Allah said: "Leave it, for soon the one who wounded it will come,' then a man from Bahz came, and he was the one who had wounded the onager. He said: 'O Messenger of Allah, it is up to you what you do with this onager,' The Messenger of Allah ordered Abu Bakr to distribute it among the people}}
\hadithdefcmd{nasai}{4345}{أَخْبَرَنَا مُحَمَّدُ بْنُ وَهْبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي أَبُو عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَبِي أُنَيْسَةَ، عَنْ أَبِي حَازِمٍ، عَنِ ابْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ أَبِي قَتَادَةَ، قَالَ أَصَابَ حِمَارًا وَحْشِيًّا فَأَتَى بِهِ أَصْحَابَهُ وَهُمْ مُحْرِمُونَ وَهُوَ حَلاَلٌ فَأَكَلْنَا مِنْهُ فَقَالَ بَعْضُهُمْ لِبَعْضٍ لَوْ سَأَلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْهُ ‏.‏ فَسَأَلْنَاهُ فَقَالَ ‏"‏ قَدْ أَحْسَنْتُمْ ‏"‏ ‏.‏ فَقَالَ لَنَا ‏"‏ هَلْ مَعَكُمْ مِنْهُ شَىْءٌ ‏"‏ ‏.‏ قُلْنَا نَعَمْ ‏.‏ قَالَ ‏"‏ فَاهْدُوا لَنَا ‏"‏ ‏.‏ فَأَتَيْنَاهُ مِنْهُ فَأَكَلَ مِنْهُ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{4345}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that from Ibn Abi Qatadah, from Abu Qatadah, that:he caught an onager and brought it to his companion's who were in Ihram whereas he was not, and they ate from it. Then they said to one another: "Let us ask the Messenger of Allah about it," So we asked him and he said:" You did well" Then he said to us: "Do you have anything left of it?" We said: "Yes." He said: "Give us some "So we brought him some, and he ate from it, while he was in Ihram}}
\hadithdefcmd{nasai}{4346}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ زَهْدَمٍ، أَنَّ أَبَا مُوسَى، أُتِيَ بِدَجَاجَةٍ فَتَنَحَّى رَجُلٌ مِنَ الْقَوْمِ فَقَالَ مَا شَأْنُكَ قَالَ إِنِّي رَأَيْتُهَا تَأْكُلُ شَيْئًا قَذِرْتُهُ فَحَلَفْتُ أَنْ لاَ آكُلَهُ ‏.‏ فَقَالَ أَبُو مُوسَى ادْنُ فَكُلْ فَإِنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْكُلُهُ ‏.‏ وَأَمَرَهُ أَنْ يُكَفِّرَ عَنْ يَمِينِهِ ‏.‏\hadithno{4346}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Zahdam that:Some chicken was brought to Abu Musa and a man moved away from the people. He said: "What is the matter with you?" He said: "I saw it eating something that I consider filthy, and I swore I would not eat it." Abu Musa said: "Come and eat, for I saw the Messenger of Allah eating it." And he told him to offer an expiation for his vow (Kafarat Al-Yamin)}}
\hadithdefcmd{nasai}{4347}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنِ الْقَاسِمِ التَّمِيمِيِّ، عَنْ زَهْدَمٍ الْجَرْمِيِّ، قَالَ كُنَّا عِنْدَ أَبِي مُوسَى فَقُدِّمَ طَعَامُهُ وَقُدِّمَ فِي طَعَامِهِ لَحْمُ دَجَاجٍ وَفِي الْقَوْمِ رَجُلٌ مِنْ بَنِي تَيْمِ اللَّهِ أَحْمَرُ كَأَنَّهُ مَوْلًى فَلَمْ يَدْنُ فَقَالَ لَهُ أَبُو مُوسَى ادْنُ فَإِنِّي قَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْكُلُ مِنْهُ ‏.‏\hadithno{4347}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zahadam Al-Jarmi said:"We were with Abu Musa and His food was brought, including chicken. Among the people there was a man from banu Taimullah who had reddish complexion, as if he were a freed slave. He did not come close and Abu Musa said: "Come (and eat) for I saw the Messenger of All eating it}}
\hadithdefcmd{nasai}{4348}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ بِشْرٍ، - هُوَ ابْنُ الْمُفَضَّلِ - قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ عَلِيِّ بْنِ الْحَكَمِ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم نَهَى يَوْمَ خَيْبَرَ عَنْ كُلِّ ذِي مِخْلَبٍ مِنَ الطَّيْرِ وَعَنْ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ ‏.‏\hadithno{4348}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that:on the Day of Khaibar, the Prophet of Allah forbade eating any birds with talons and any predators with fangs. (Daif)}}
\hadithdefcmd{nasai}{4349}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمُقْرِئُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ صُهَيْبٍ، مَوْلَى ابْنِ عَامِرٍ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا مِنْ إِنْسَانٍ قَتَلَ عُصْفُورًا فَمَا فَوْقَهَا بِغَيْرِ حَقِّهَا إِلاَّ سَأَلَهُ اللَّهُ عَزَّ وَجَلَّ عَنْهَا ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَمَا حَقُّهَا قَالَ ‏"‏ يَذْبَحُهَا فَيَأْكُلُهَا وَلاَ يَقْطَعُ رَأْسَهَا يَرْمِي بِهَا ‏"‏ ‏.‏\hadithno{4349}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that the Messenger of Allah said:"There is no person who kills a small bird or anything larger for no just reason, but Allah, the Mighty and Sublime, will ask him about it." It was said: "O Messenger of Allah, what does just reason;' mean?" Her said: "That you slaughter it and eat it, and do not cut off its head and throw it aside}}
\hadithdefcmd{nasai}{4350}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ سَعِيدِ بْنِ سَلَمَةَ، عَنِ الْمُغِيرَةِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي مَاءِ الْبَحْرِ ‏ "‏ هُوَ الطَّهُورُ مَاؤُهُ الْحَلاَلُ مَيْتَتُهُ ‏"‏ ‏.‏\hadithno{4350}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah, that the Prophet (said), concerning the water of the sea:"Its water is pure (and Purification) and its 'dead meat' is permissible (to eat)}}
\hadithdefcmd{nasai}{4351}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، قَالَ حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَعَثَنَا النَّبِيُّ صلى الله عليه وسلم وَنَحْنُ ثَلاَثُمِائَةٍ نَحْمِلُ زَادَنَا عَلَى رِقَابِنَا فَفَنِيَ زَادُنَا حَتَّى كَانَ يَكُونُ لِلرَّجُلِ مِنَّا كُلَّ يَوْمٍ تَمْرَةٌ ‏.‏ فَقِيلَ لَهُ يَا أَبَا عَبْدِ اللَّهِ وَأَيْنَ تَقَعُ التَّمْرَةُ مِنَ الرَّجُلِ قَالَ لَقَدْ وَجَدْنَا فَقْدَهَا حِينَ فَقَدْنَاهَا فَأَتَيْنَا الْبَحْرَ فَإِذَا بِحُوتٍ قَذَفَهُ الْبَحْرُ فَأَكَلْنَا مِنْهُ ثَمَانِيَةَ عَشَرَ يَوْمًا ‏.‏\hadithno{4351}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Jabir bin 'Abdulah saida:"The Prophet sent us, a group of three hundred, and we carried our provision on our mounts. Our supplies ran our until each man of us had one date per day." It was said to him: "O Abu'Abdullah , what good is one date for a man?" he said: "When we ran out of dates it became very difficult for us. Then we found a whale that had been cast ashore by the sea. And we ate from it for eight days}}
\hadithdefcmd{nasai}{4352}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ جَابِرًا، يَقُولُ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثَمِائَةِ رَاكِبٍ أَمِيرُنَا أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ نَرْصُدُ عِيرَ قُرَيْشٍ فَأَقَمْنَا بِالسَّاحِلِ فَأَصَابَنَا جُوعٌ شَدِيدٌ حَتَّى أَكَلْنَا الْخَبَطَ - قَالَ - فَأَلْقَى الْبَحْرُ دَابَّةً يُقَالُ لَهَا الْعَنْبَرُ فَأَكَلْنَا مِنْهُ نِصْفَ شَهْرٍ وَادَّهَنَّا مِنْ وَدَكِهِ فَثَابَتْ أَجْسَامُنَا وَأَخَذَ أَبُو عُبَيْدَةَ ضِلَعًا مِنْ أَضْلاَعِهِ فَنَظَرَ إِلَى أَطْوَلِ جَمَلٍ وَأَطْوَلِ رَجُلٍ فِي الْجَيْشِ فَمَرَّ تَحْتَهُ ثُمَّ جَاعُوا فَنَحَرَ رَجُلٌ ثَلاَثَ جَزَائِرَ ثُمَّ جَاعُوا فَنَحَرَ رَجُلٌ ثَلاَثَ جَزَائِرَ ثُمَّ جَاعُوا فَنَحَرَ رَجُلٌ ثَلاَثَ جَزَائِرَ ثُمَّ نَهَاهُ أَبُو عُبَيْدَةَ ‏.‏ قَالَ سُفْيَانُ قَالَ أَبُو الزُّبَيْرِ عَنْ جَابِرٍ فَسَأَلْنَا النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ هَلْ مَعَكُمْ مِنْهُ شَىْءٌ ‏"‏ ‏.‏ قَالَ فَأَخْرَجْنَا مِنْ عَيْنَيْهِ كَذَا وَكَذَا قُلَّةً مِنْ وَدَكٍ وَنَزَلَ فِي حِجَاجِ عَيْنِهِ أَرْبَعَةُ نَفَرٍ وَكَانَ مَعَ أَبِي عُبَيْدَةَ جِرَابٌ فِيهِ تَمْرٌ فَكَانَ يُعْطِينَا الْقَبْضَةَ ثُمَّ صَارَ إِلَى التَّمْرَةِ فَلَمَّا فَقَدْنَاهَا وَجَدْنَا فَقْدَهَا ‏.‏\hadithno{4352}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Amr said:"I heard Jabir say: 'The Messenger of Allah sent us, three hundred riders led by Abu 'Ubaidah bin al-Jarrah, to lie in wait for the caravan of the Quraish. We stayed on the coast and became very hungry, so much so that we ate Khabat. Then the sea cast ashore a beast called (Al-'Anbar), and we ate from it for half a month, and daubed our bodies with its fat, and our health was restored. Abu 'Ubaidah took one it its ribs and looked for the tallest camel and the tallest man in the army, and he passed beneath it. Then they got hungry again and a man slaughtered three camels, then they got hungry and a man slaughtered three camels, then they got hungry and a man slaughtered three camels, then they got hungry and a man slaughtered three camels. Then Abu 'Ubaidah told him not to do that." (One of the narrators) Sufyan said: "Abu Az-Zubair said, narrating from Jabir: "We asked the Prophet and he said: 'Do you have anything left of it?"' he said; "We took out, such-and -such an amount of a fat from its (the whale's) eyes, and four men could fit into its eye socket. Abu 'Ubaidah had a sack of dates and he used to give them out by the handful, then he started to give one date at a time, and when we ran out of dates it became very difficult for us}}
\hadithdefcmd{nasai}{4353}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ بَعَثَنَا النَّبِيُّ صلى الله عليه وسلم مَعَ أَبِي عُبَيْدَةَ فِي سَرِيَّةٍ فَنَفِدَ زَادُنَا فَمَرَرْنَا بِحُوتٍ قَدْ قَذَفَ بِهِ الْبَحْرُ فَأَرَدْنَا أَنْ نَأْكُلَ مِنْهُ فَنَهَانَا أَبُو عُبَيْدَةَ ثُمَّ قَالَ نَحْنُ رُسُلُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي سَبِيلِ اللَّهِ كُلُوا ‏.‏ فَأَكَلْنَا مِنْهُ أَيَّامًا فَلَمَّا قَدِمْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَخْبَرْنَاهُ فَقَالَ ‏ "‏ إِنْ كَانَ بَقِيَ مَعَكُمْ شَىْءٌ فَابْعَثُوا بِهِ إِلَيْنَا ‏"‏ ‏.‏\hadithno{4353}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Prophet sent us with Abu 'Ubaidah on a campaign. Our supplies ran out. Then we passed by a whale that had been cast ashore by the sea. We wanted to eat from it, but Abu 'Ubaidah told us not to. Then he said: 'We are the envoys of the Messenger of Allah for the sake of Allah, so eat. So we ate from it for several days. When we came to the messenger of Allah we told him about that and he said: 'If you have anything left of it then send it to us}}
\hadithdefcmd{nasai}{4354}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيِّ بْنِ مُقَدَّمٍ الْمُقَدَّمِيُّ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ أَبِي عُبَيْدَةَ وَنَحْنُ ثَلاَثُمِائَةٍ وَبِضْعَةَ عَشَرَ وَزَوَّدَنَا جِرَابًا مِنْ تَمْرٍ فَأَعْطَانَا قَبْضَةً قَبْضَةً فَلَمَّا أَنْ جُزْنَاهُ أَعْطَانَا تَمْرَةً تَمْرَةً حَتَّى إِنْ كُنَّا لَنَمُصُّهَا كَمَا يَمُصُّ الصَّبِيُّ وَنَشْرَبُ عَلَيْهَا الْمَاءَ فَلَمَّا فَقَدْنَاهَا وَجَدْنَا فَقْدَهَا حَتَّى إِنْ كُنَّا لَنَخْبِطُ الْخَبَطَ بِقِسِيِّنَا وَنَسَفُّهُ ثُمَّ نَشْرَبُ عَلَيْهِ مِنَ الْمَاءِ حَتَّى سُمِّينَا جَيْشَ الْخَبَطِ ثُمَّ أَجَزْنَا السَّاحِلَ فَإِذَا دَابَّةٌ مِثْلُ الْكَثِيبِ يُقَالُ لَهُ الْعَنْبَرُ فَقَالَ أَبُو عُبَيْدَةَ مَيْتَةٌ لاَ تَأْكُلُوهُ ‏.‏ ثُمَّ قَالَ جَيْشُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ وَنَحْنُ مُضْطَرُّونَ كُلُوا بِاسْمِ اللَّهِ ‏.‏ فَأَكَلْنَا مِنْهُ وَجَعَلْنَا مِنْهُ وَشِيقَةً وَلَقَدْ جَلَسَ فِي مَوْضِعِ عَيْنِهِ ثَلاَثَةَ عَشَرَ رَجُلاً - قَالَ - فَأَخَذَ أَبُو عُبَيْدَةَ ضِلَعًا مِنْ أَضْلاَعِهِ فَرَحَلَ بِهِ أَجْسَمَ بَعِيرٍ مِنْ أَبَاعِرِ الْقَوْمِ فَأَجَازَ تَحْتَهُ فَلَمَّا قَدِمْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا حَبَسَكُمْ ‏"‏ ‏.‏ قُلْنَا كُنَّا نَتَّبِعُ عِيرَاتِ قُرَيْشٍ وَذَكَرْنَا لَهُ مِنْ أَمْرِ الدَّابَّةِ فَقَالَ ‏"‏ ذَاكَ رِزْقٌ رَزَقَكُمُوهُ اللَّهُ عَزَّ وَجَلَّ أَمَعَكُمْ مِنْهُ شَىْءٌ ‏"‏ ‏.‏ قَالَ قُلْنَا نَعَمْ ‏.‏\hadithno{4354}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{(It was narrated that Jabir said:"The Messenger of Allah sent us with Abu Ubaidah and we numbered over three hundred men. He supplied us with a sack of dates and gave them out by the handful. When he ran short, he gave us one date at a time, until we used to suck on it like an infant, and we would drink water with it. When we ran out of them it became very difficult for us. We used to hit the Khabat leaves with our bows to knock them down) and swallow them, then drink water with it. We became known as Jaish Al-Khabat (the Khabat army). Then, when we were about to turn inland, we saw a beast like a hill, caloled Al-'Anbar. Abu 'Ubaidah said: 'It is dead meat, do not eat it.' Then he said: 'The army of the Messenger of Allah in the cause of Allah, the Mighty and Sublime, and we are forced by necessity; eat in the name of Allah. 'So we arte from it and we made some if it into jerked meat. Thirteen men could sit in its eye-socket. Abu Ubaidah took one of its ribs and seated a man on the biggest camel that the people had, and they passed beneath it. When we came to the Messenger of Allah, he said: 'What kept you so long?' We said: The Quraish' and we told him about the beast. He said: 'That is provision that Allah granted to you. Do you have anything of it with you? "We said: ' Yes}}
\hadithdefcmd{nasai}{4355}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدِ بْنِ خَالِدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عُثْمَانَ، أَنَّ طَبِيبًا، ذَكَرَ ضِفْدَعًا فِي دَوَاءٍ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ قَتْلِهِ ‏.‏\hadithno{4355}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdur-Rahman bin 'Uthman that:a physician made mention of the use of frogs in a remedy in the presence of the Messenger of Allah and the Messengher of Allah forbade killing them. (sahih)}}
\hadithdefcmd{nasai}{4356}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ سُفْيَانَ، - وَهُوَ ابْنُ حَبِيبٍ - عَنْ شُعْبَةَ، عَنْ أَبِي يَعْفُورٍ، سَمِعَ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، قَالَ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم سَبْعَ غَزَوَاتٍ فَكُنَّا نَأْكُلُ الْجَرَادَ ‏.‏\hadithno{4356}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Ya fur that he heard 'Abdullah bin Abi Awfa says:"We went on seven campaigns with the Messenger of Allah and we used to eat locusts}}
\hadithdefcmd{nasai}{4357}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ سُفْيَانَ، - وَهُوَ ابْنُ عُيَيْنَةَ - عَنْ أَبِي يَعْفُورٍ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى عَنْ قَتْلِ الْجَرَادِ، فَقَالَ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم سِتَّ غَزَوَاتٍ نَأْكُلُ الْجَرَادَ ‏.‏\hadithno{4357}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abuy ya fur said:"I asked 'Abdullah bin Abu Awfa about killing locusts and he said: I went on six campaigns with the Messenger of Allah hand we ate locusts}}
\hadithdefcmd{nasai}{4358}{أَخْبَرَنَا وَهْبُ بْنُ بَيَانٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَّ نَمْلَةً قَرَصَتْ نَبِيًّا مِنَ الأَنْبِيَاءِ فَأَمَرَ بِقَرْيَةِ النَّمْلِ فَأُحْرِقَتْ فَأَوْحَى اللَّهُ عَزَّ وَجَلَّ إِلَيْهِ أَنْ قَدْ قَرَصَتْكَ نَمْلَةٌ أَهْلَكْتَ أُمَّةً مِنَ الأُمَمِ تُسَبِّحُ ‏"‏ ‏.‏\hadithno{4358}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Was narrated from Abu Hurairah from the Messenger of Allah:"An ant bit one of the prophets, and he ordered that the ant nest be burned. Then Allah revealed to him: "One ant bit you, and you destroyed one of the nations that glorify Allah}}
\hadithdefcmd{nasai}{4359}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا النَّضْرُ، - وَهُوَ ابْنُ شُمَيْلٍ - قَالَ أَنْبَأَنَا أَشْعَثُ، عَنِ الْحَسَنِ، نَزَلَ نَبِيٌّ مِنَ الأَنْبِيَاءِ تَحْتَ شَجَرَةٍ فَلَدَغَتْهُ نَمْلَةٌ فَأَمَرَ بِبَيْتِهِنَّ فَحُرِّقَ عَلَى مَا فِيهَا فَأَوْحَى اللَّهُ إِلَيْهِ فَهَلاَّ نَمْلَةً وَاحِدَةً ‏.‏ وَقَالَ الأَشْعَثُ عَنِ ابْنِ سِيرِينَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ وَزَادَ فَإِنَّهُنَّ يُسَبِّحْنَ ‏.‏\hadithno{4359}\hadithgrade{Abu Ghuddah: Sahih Maqtu; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from al-Hasan:"One of the prophets stopped beneath a tree and an ant bit him, so he gave instructions that their nest be burned with all the ants inside it. Then Allah revealed to him" 'Why did you not punish just one ant?" Al-Ash' ath said: "A similar report was narrated from Ibn Sirin, from Abu Hurairah, from the Prophet, in which were added the words: 'for they glorify Allah}}
\hadithdefcmd{nasai}{4360}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، نَحْوَهُ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{4360}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Narrated from Abu Hurairah:A similar report was narrated from Abu Hurairah, but was not attributed to the Prophet}}
